@@ -4,9 +4,9 @@ package Task::Kensho::ModuleDev;
 BEGIN {
   $Task::Kensho::ModuleDev::AUTHORITY = 'cpan:PERIGRIN';
 }
-# git description: v0.34001-TRIAL-15-g4bd2afa
-$Task::Kensho::ModuleDev::VERSION = '0.34002'; # TRIAL
-# ABSTRACT: Module Development
+# git description: v0.34002-TRIAL-20-gae11a02
+$Task::Kensho::ModuleDev::VERSION = '0.34003'; # TRIAL
+# ABSTRACT: A Glimpse at an Enlightened Perl: Module Development
 
 __END__
 
@@ -16,11 +16,11 @@ __END__
 
 =head1 NAME
 
-Task::Kensho::ModuleDev - Module Development
+Task::Kensho::ModuleDev - A Glimpse at an Enlightened Perl: Module Development
 
 =head1 VERSION
 
-version 0.34002
+version 0.34003
 
 =head1 SYNOPSIS
 
@@ -38,88 +38,100 @@ Kenshō (見性) (C. Wu) is a Japanese term for enlightenment
 experiences - most commonly used within the confines of Zen
 Buddhism - literally meaning "seeing one's nature"[1] or "true
 self."[2] It generally "refers to the realization of nonduality of
+subject and object."[3]
 
 =back
 
-Task::Kensho is a first cut at building a list of recommended modules
+L<Task::Kensho> is a first cut at building a list of recommended modules
 for Enlightened Perl development. CPAN is wonderful, but there are too
 many wheels and you have to pick and choose amongst the various
 competing technologies.
 
-The plan is for Task::Kensho to be a rough testing ground for ideas that
+The plan is for L<Task::Kensho> to be a rough testing ground for ideas that
 go into among other things the Enlightened Perl Organisation Extended
 Core (EPO-EC).
 
-The modules that are bundled by Task::Kensho are broken down into
+The modules that are bundled by L<Task::Kensho> are broken down into
 several categories and are still being considered. They are all taken
 from various top 100 most used perl modules lists and from discussions
 with various subject matter experts in the Perl Community. That said,
 this bundle does I<not> follow the guidelines established for the EPO-EC
 for peer review via industry advisers.
 
-Starting in 2011, Task::Kensho split its sub-groups of modules into
-individually-installable tasks. These individual tasks will always install all
-their modules by default. This facilitates the ease and simplicity the
-distribution aims to achieve. Each Task::Kensho sub-task is listed at the
+Starting in 2011, L<Task::Kensho> split its sub-groups of modules into
+individually-installable tasks.  Each L<Task::Kensho> sub-task is listed at the
 beginning of its section in this documentation.
 
-=head2 Module Development: Task::Kensho::ModuleDev
+When installing L<Task::Kensho> itself, you will be asked to install each
+sub-task in turn, or you can install individual tasks separately. These
+individual tasks will always install all their modules by default. This
+facilitates the ease and simplicity the distribution aims to achieve.
+
+=head1 RECOMMENDED MODULES
+
+=head2 L<Task::Kensho::ModuleDev>: Module Development
 
 =for stopwords profiler templated
 
-=over 4
-
-=item L<CPAN::Uploader>
+=head3 L<CPAN::Uploader>
 
 Upload things to the CPAN
 
-=item L<Carp::Always>
+=head3 L<Carp::Always>
 
 Warns and dies noisily with stack backtraces
 
-=item L<Devel::NYTProf>
+=head3 L<Devel::NYTProf>
 
 Powerful feature-rich perl source code profiler
 
-=item L<Dist::Zilla>
+=head3 L<Dist::Zilla>
 
 Builds distributions of code to be uploaded to the CPAN.
 
-=item L<Modern::Perl>
+=head3 L<Modern::Perl>
 
 enable all of the features of Modern Perl with one command
 
-=item L<Module::Install>
+=head3 L<Module::Install>
 
 Standalone, extensible Perl module installer
 
-=item L<Perl::Critic>
+=head3 L<Perl::Critic>
 
 Critique Perl source code for best-practices.
 
-=item L<Perl::Tidy>
+=head3 L<Perl::Tidy>
 
 Parses and beautifies perl source
 
-=item L<Perl::Version>
+=head3 L<Perl::Version>
 
 Parse and manipulate Perl version strings
 
-=item L<Pod::Readme>
+=head3 L<Pod::Readme>
 
 Convert POD to README file
 
-=item L<Software::License>
+=head3 L<Software::License>
 
 Packages that provide templated software licenses
 
-=back
+=head1 INSTALLING
+
+Since version 0.34, L<Task::Kensho> has made use of the C<optional_features> field
+in distribution metadata. This allows CPAN clients to interact with you
+regarding which modules you wish to install.
+
+The C<cpanm> client requires interactive mode to be enabled for this to work:
+
+    cpanm --interactive Task-Kensho
 
 =head1 RELEASE SCHEDULE
 
-Starting with release 0.18 Task::Kensho was moved to a monthly release
+Starting with release 0.18, L<Task::Kensho> was moved to a monthly release
 cycle. This will facilitate a consistent schedule for upstream vendors
-to track the changes in Task::Kensho.
+to track the changes in L<Task::Kensho>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -130,8 +142,7 @@ better for you. This is however a path to good perl practice, and a
 starting place on the road to Enlightened Perl programming.
 
 Please report any bugs or feature requests to
-C<bug-task-kensho@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
 =head1 SEE ALSO
 
